"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _reactNative = require("react-native");

var _uuid = require("uuid");

var _reactNativeBackgroundUpload = _interopRequireDefault(require("react-native-background-upload"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const VideoCompressEventEmitter = new _reactNative.NativeEventEmitter(_reactNative.NativeModules.VideoCompressor);
const NativeVideoCompressor = _reactNative.NativeModules.VideoCompressor;
const Video = {
  compress: async (fileUrl, options, onProgress) => {
    const uuid = (0, _uuid.v4)();
    let subscription = null;

    try {
      if (onProgress) {
        subscription = VideoCompressEventEmitter.addListener('videoCompressProgress', event => {
          if (event.uuid === uuid) {
            onProgress(event.data.progress);
          }
        });
      }

      const modifiedOptions = {
        uuid
      };
      if (options !== null && options !== void 0 && options.bitrate) modifiedOptions.bitrate = options === null || options === void 0 ? void 0 : options.bitrate;
      const result = await NativeVideoCompressor.compress(fileUrl, modifiedOptions);
      return result;
    } finally {
      if (subscription) {
        VideoCompressEventEmitter.removeSubscription(subscription);
      }
    }
  },
  backgroundUpload: async (url, fileUrl, options, onProgress) => {
    if (!NativeVideoCompressor || !NativeVideoCompressor.upload) {
      //check if expo can upload the file
      const scheme = fileUrl.split('://')[0];

      if (['file'].includes(scheme)) {
        return _reactNativeBackgroundUpload.default.startUpload({
          url: url,
          path: fileUrl,
          method: options.httpMethod || 'PUT',
          type: 'raw'
        }).then(uploadId => {
          console.log('Upload started');

          _reactNativeBackgroundUpload.default.addListener('progress', uploadId, data => onProgress && onProgress(parseInt(data.progress), 100));

          _reactNativeBackgroundUpload.default.addListener('error', uploadId, data => {
            throw data.error;
          });
        }).catch(err => {
          throw err;
        }); //fallback to use expo upload
        // return FileSystem.uploadAsync(url, fileUrl, options);
      } else {
        // Use poor old fetch
        const fileRes = await fetch(fileUrl);
        const fileBody = await fileRes.blob();
        return fetch(url, {
          method: options.httpMethod,
          body: fileBody,
          headers: options.headers
        });
      }
    }

    const uuid = (0, _uuid.v4)();
    let subscription = null;

    try {
      if (onProgress) {
        subscription = VideoCompressEventEmitter.addListener('VideoCompressorProgress', event => {
          if (event.uuid === uuid) {
            onProgress(event.data.written, event.data.total);
          }
        });
      }

      if (_reactNative.Platform.OS === 'android' && fileUrl.includes('file://')) {
        fileUrl = fileUrl.replace('file://', '');
      }

      const result = await NativeVideoCompressor.upload(fileUrl, {
        uuid,
        method: options.httpMethod,
        headers: options.headers,
        url
      });
      return result;
    } finally {
      if (subscription) {
        VideoCompressEventEmitter.removeSubscription(subscription);
      }
    }
  },

  activateBackgroundTask(onExpired) {
    if (onExpired) {
      const subscription = VideoCompressEventEmitter.addListener('backgroundTaskExpired', event => {
        onExpired(event);
        VideoCompressEventEmitter.removeSubscription(subscription);
      });
    }

    return NativeVideoCompressor.activateBackgroundTask({});
  },

  deactivateBackgroundTask() {
    VideoCompressEventEmitter.removeAllListeners('backgroundTaskExpired');
    return NativeVideoCompressor.deactivateBackgroundTask({});
  }

};
var _default = Video;
exports.default = _default;
//# sourceMappingURL=index.js.map